@@ -558,16 +558,40 @@ def start_monitoring_anki():
 
 # --- Anki Stats Kanji Extraction Utilities ---
 
-def get_all_anki_first_field_kanji():
+def get_anki_earliest_date():
+    """
+    Fetches the earliest Anki card ID.
+    """
+    try:
+        note_ids = invoke("findCards", query="")
+        if not note_ids:
+            return 0
+        
+        # Return the first card ID as the "earliest"
+        # return note_ids[0]
+        return min(note_ids)
+        
+    except Exception as e:
+        logger.error(f"Failed to fetch kanji from Anki: {e}")
+        return 0
+
+def get_all_anki_first_field_kanji(start_timestamp = None, end_timestamp = None):
     """
     Fetch all notes from Anki and extract unique kanji from the first field of each note.
     Returns a set of kanji characters.
+    Optional filtering by start_timestamp and end_timestamp on note IDs.
     """
     from GameSentenceMiner.web.stats import is_kanji
     try:
         note_ids = invoke("findNotes", query="")
         if not note_ids:
             return set()
+        
+        # Filter note IDs by start and end timestamps if provided
+        if (start_timestamp and end_timestamp):
+            note_ids = [nid for nid in note_ids if int(start_timestamp) <= nid <= int(end_timestamp)]
+            if not note_ids:
+                return set()
         kanji_set = set()
         batch_size = 1000
         for i in range(0, len(note_ids), batch_size):
